@@ -38,7 +38,7 @@ read_data <- function(x, nrows = -1){
   setNames(tmp, tolower(nmz))
 }
 
-read_all <- function(x, fmt, read, ncdf) {
+read_all <- function(x, fmt, read) {
   switch(fmt,
          csv = {
            if (read) {
@@ -49,15 +49,9 @@ read_all <- function(x, fmt, read, ncdf) {
          },
          nc = {
            if (read) {
-             switch(ncdf,
-                    ncdf = ncdf_get(x),
-                    ncdf4 = ncdf4_get(x)
-             )
+             ncdf4_get(x)
            } else {
-             switch(ncdf,
-                    ncdf = ncdf_summary(x),
-                    ncdf4 = ncdf4_summary(x)
-             )
+             ncdf_summary(x)
            }
          }
   )
@@ -98,3 +92,19 @@ err_handle <- function(x, store, key) {
     stop(paste0(mssg, collapse = "\n\n"), call. = FALSE)
   }
 }
+
+err_handle2 <- function(x) {
+  if (x$status_code > 201) {
+    tt <- content(x, "text")
+    mssg <- xml_text(xml_find_all(read_html(tt), "//h1"))
+    stop(paste0(mssg, collapse = "\n\n"), call. = FALSE)
+  }
+}
+
+erdddap_GET <- function(url, args = NULL, ...) {
+  tt <- GET(url, query = args, ...)
+  err_handle2(tt)
+  stopifnot(tt$headers$`content-type` == 'application/json;charset=UTF-8')
+  out <- content(tt, as = "text")
+  jsonlite::fromJSON(out, FALSE)
+}
